==> DSS-4.2.5.tar.gz: DSS-4.2.5/SMTP/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by PJNSMTPApp.rc
//
#define IDD_MAIN_DIALOG                 102
#define IDR_MAINFRAME                   128
#define IDD_CONFIGURATION               129
#define IDD_PROGRESS                    130
#define IDS_PJNSMTP_UNEXPECTED_SMTP_LOGIN_RESPONSE 512
#define IDS_PJNSMTP_UNEXPECTED_EHLO_RESPONSE 516
#define IDS_PJNSMTP_UNEXPECTED_HELO_RESPONSE 517
#define IDS_PJNSMTP_UNEXPECTED_QUIT_RESPONSE 518
#define IDS_PJNSMTP_UNEXPECTED_MAIL_FROM_RESPONSE 519
#define IDS_PJNSMTP_UNEXPECTED_DATA_RESPONSE 520
#define IDS_PJNSMTP_UNEXPECTED_END_OF_MESSAGE_RESPONSE 521
#define IDS_PJNSMTP_FILE_SIZE_TO_SEND_TOO_LARGE 522
#define IDS_PJNSMTP_CANNOT_SEND_ZERO_BYTE_MESSAGE 523
#define IDS_PJNSMTP_UNEXPECTED_RCPT_TO_RESPONSE 524
#define IDS_PJNSMTP_UNEXPECTED_AUTH_LOGIN_RESPONSE 525
#define IDS_PJNSMTP_UNEXPECTED_AUTH_LOGIN_USERNAME_REQUEST 526
#define IDS_PJNSMTP_UNEXPECTED_AUTH_LOGIN_USERNAME_RESPONSE 527
#define IDS_PJNSMTP_UNEXPECTED_AUTH_LOGIN_PASSWORD_REQUEST 528
#define IDS_PJNSMTP_UNEXPECTED_AUTH_LOGIN_PASSWORD_RESPONSE 529
#define IDS_PJNSMTP_UNEXPECTED_AUTH_PLAIN_RESPONSE 530
#define IDS_PJNSMTP_UNEXPECTED_AUTH_PLAIN_USERNAME_REQUEST 531
#define IDS_PJNSMTP_UNEXPECTED_AUTH_PLAIN_USERNAME_RESPONSE 532
#define IDS_PJNSMTP_UNEXPECTED_AUTH_PLAIN_PASSWORD_REQUEST 533
#define IDS_PJNSMTP_UNEXPECTED_AUTH_PLAIN_PASSWORD_RESPONSE 534
#define IDS_PJNSMTP_UNEXPECTED_AUTH_CRAM_MD5_RESPONSE 535
#define IDS_PJNSMTP_UNEXPECTED_CRAMD_MD5_DIGEST_RESPONSE 536
#define IDS_PJNSMTP_FAILED_NTLM_AUTHENTICATION 537
#define IDS_PJNSMTP_UNEXPECTED_AUTH_NTLM_RESPONSE 538
#define IDS_PJNSMTP_FAIL_BASE64_DECODE  539
#define IDS_PJNSMTP_FAIL_BASE64_ENCODE  540
#define IDS_PJNSMTP_FAIL_CREATE_SSL_SOCKET 541
#define IDS_PJNSMTP_FAIL_CONNECT_SOCKS4_VIASSL 542
#define IDS_PJNSMTP_FAIL_CONNECT_SOCKS5_VIASSL 543
#define IDS_PJNSMTP_FAIL_CONNECT_HTTPPROXY_VIASSL 544
#define IDS_PJNSMTP_FAIL_CONNECT_VIASSL 545
#define IDS_PJNSMTP_FAIL_SEND_VIASSL    546
#define IDS_PJNSMTP_FAIL_RECEIVE_VIASSL 547
#define IDC_TO                          1000
#define IDC_CC                          1001
#define IDC_BCC                         1002
#define IDC_SUBJECT                     1003
#define IDC_BODY                        1004
#define IDC_FILE                        1005
#define IDC_BROWSE_FILE                 1006
#define IDC_SEND                        1007
#define IDC_CONFIGURATION               1008
#define IDC_NAME                        1009
#define IDC_ADDRESS                     1010
#define IDC_HOST                        1011
#define IDC_PORT                        1012
#define IDC_USERNAME                    1014
#define IDC_PASSWORD                    1015
#define IDC_PROMPT_USERNAME             1016
#define IDC_PROMPT_PASSWORD             1017
#define IDC_AUTH                        1018
#define IDC_AUTOCONNECT                 1019
#define IDC_IPS                         1020
#define IDC_ENCODING                    1021
#define IDC_MIME                        1022
#define IDC_HTML                        1023
#define IDC_SAVE                        1024
#define IDC_PRIORITY                    1024
#define IDC_SEND_FROM_DISK              1025
#define IDC_DIRECTLY                    1026
#define IDC_PROGRESS1                   1027
#define IDC_DNS_LOOKUP                  1027
#define IDC_SSL                         1029
#define IDC_DSN                         1030
#define IDC_DSN_SUCCESS                 1031
#define IDC_DSN_FAILURE                 1032
#define IDC_DSN_DELAY                   1033
#define IDC_DSN_HEADERS                 1034

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        132
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1035
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> DSS-5.1.5.tar.gz: DSS-5.1.5/SMTP/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by PJNSMTPApp.rc
//
#define IDD_MAIN_DIALOG                 102
#define IDR_MAINFRAME                   128
#define IDD_CONFIGURATION               129
//#define IDD_PROGRESS                    130
#define IDS_PJNSMTP_UNEXPECTED_SMTP_LOGIN_RESPONSE 512
#define IDS_PJNSMTP_UNEXPECTED_EHLO_RESPONSE 516
#define IDS_PJNSMTP_UNEXPECTED_HELO_RESPONSE 517
#define IDS_PJNSMTP_UNEXPECTED_QUIT_RESPONSE 518
#define IDS_PJNSMTP_UNEXPECTED_MAIL_FROM_RESPONSE 519
#define IDS_PJNSMTP_UNEXPECTED_DATA_RESPONSE 520
#define IDS_PJNSMTP_UNEXPECTED_END_OF_MESSAGE_RESPONSE 521
#define IDS_PJNSMTP_FILE_SIZE_TO_SEND_TOO_LARGE 522
#define IDS_PJNSMTP_CANNOT_SEND_ZERO_BYTE_MESSAGE 523
#define IDS_PJNSMTP_UNEXPECTED_RCPT_TO_RESPONSE 524
#define IDS_PJNSMTP_UNEXPECTED_AUTH_LOGIN_RESPONSE 525
#define IDS_PJNSMTP_UNEXPECTED_AUTH_LOGIN_USERNAME_REQUEST 526
#define IDS_PJNSMTP_UNEXPECTED_AUTH_LOGIN_USERNAME_RESPONSE 527
#define IDS_PJNSMTP_UNEXPECTED_AUTH_LOGIN_PASSWORD_REQUEST 528
#define IDS_PJNSMTP_UNEXPECTED_AUTH_LOGIN_PASSWORD_RESPONSE 529
#define IDS_PJNSMTP_UNEXPECTED_AUTH_PLAIN_RESPONSE 530
#define IDS_PJNSMTP_UNEXPECTED_AUTH_PLAIN_USERNAME_REQUEST 531
#define IDS_PJNSMTP_UNEXPECTED_AUTH_PLAIN_USERNAME_RESPONSE 532
#define IDS_PJNSMTP_UNEXPECTED_AUTH_PLAIN_PASSWORD_REQUEST 533
#define IDS_PJNSMTP_UNEXPECTED_AUTH_PLAIN_PASSWORD_RESPONSE 534
#define IDS_PJNSMTP_UNEXPECTED_AUTH_CRAM_MD5_RESPONSE 535
#define IDS_PJNSMTP_UNEXPECTED_CRAMD_MD5_DIGEST_RESPONSE 536
#define IDS_PJNSMTP_FAILED_NTLM_AUTHENTICATION 537
#define IDS_PJNSMTP_UNEXPECTED_AUTH_NTLM_RESPONSE 538
#define IDS_PJNSMTP_FAIL_BASE64_DECODE  539
#define IDS_PJNSMTP_FAIL_BASE64_ENCODE  540
#define IDS_PJNSMTP_FAIL_CREATE_SSL_SOCKET 541
#define IDS_PJNSMTP_FAIL_CONNECT_SOCKS4_VIASSL 542
#define IDS_PJNSMTP_FAIL_CONNECT_SOCKS5_VIASSL 543
#define IDS_PJNSMTP_FAIL_CONNECT_HTTPPROXY_VIASSL 544
#define IDS_PJNSMTP_FAIL_CONNECT_VIASSL 545
#define IDS_PJNSMTP_FAIL_SEND_VIASSL    546
#define IDS_PJNSMTP_FAIL_RECEIVE_VIASSL 547
#define IDC_TO                          1000
#define IDC_CC                          1001
#define IDC_BCC                         1002
#define IDC_SUBJECT                     1003
#define IDC_BODY                        1004
#define IDC_FILE                        1005
#define IDC_BROWSE_FILE                 1006
#define IDC_SEND                        1007
#define IDC_CONFIGURATION               1008
#define IDC_NAME                        1009
#define IDC_ADDRESS                     1010
#define IDC_HOST                        1011
#define IDC_PORT                        1012
#define IDC_USERNAME                    1014
#define IDC_PASSWORD                    1015
#define IDC_PROMPT_USERNAME             1016
#define IDC_PROMPT_PASSWORD             1017
#define IDC_AUTH                        1018
#define IDC_AUTOCONNECT                 1019
#define IDC_IPS                         1020
#define IDC_ENCODING                    1021
#define IDC_MIME                        1022
#define IDC_HTML                        1023
#define IDC_SAVE                        1024
#define IDC_PRIORITY                    1024
#define IDC_SEND_FROM_DISK              1025
#define IDC_DIRECTLY                    1026
#define IDC_PROGRESS1                   1027
#define IDC_DNS_LOOKUP                  1027
#define IDC_SSL                         1029
#define IDC_DSN                         1030
#define IDC_DSN_SUCCESS                 1031
#define IDC_DSN_FAILURE                 1032
#define IDC_DSN_DELAY                   1033
#define IDC_DSN_HEADERS                 1034

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        132
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1035
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
